@@ -5,7 +5,7 @@ use strict;
 
 require Exporter;
 
-our $VERSION = "v1.0.2";
+our $VERSION = "v1.0.3";
 our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ("all" => [ qw(
 	extractHairpins
@@ -131,12 +131,12 @@ sub extractHairpins($ $ $ $ $){
 				}
 				my $numHairpinLoops = scalar(@hairpinLoopStartPos);
 			
-				#If window contains no hairpin loop, ignore
+				#If subwindow contains no hairpin loop, ignore
 				if($numHairpinLoops == 0){
 					next;
 				}
 			
-				#Iterate over all hairpin loops in window
+				#Iterate over all hairpin loops in subwindow
 				my @strArray = split("", $str);
 				foreach my $index (0 .. scalar(@hairpinLoopStartPos) - 1){
 					my $startPos = $hairpinLoopStartPos[$index];
@@ -312,10 +312,9 @@ sub extractHairpins($ $ $ $ $){
 					#Write hairpin to output files
 					my $lociStart = $windowStart + $startPos + 1 - $fiveNumNuc;
 					my $lociEnd = $lociStart + $fiveNumNuc + $loopLen + $threeNumNuc;
-					my @hairpinArray = ("HP:$SPECIES_CODE:$chr:$lociStart-$lociEnd", $hairpinSeq, $hairpinStr, "$chr:$lociStart-$lociEnd", $winID, $hairpinSeqLen, $cgComp, $trSig, $stemLen, $loopLen, $stembpProp, $upStrNor, $upLenNor, $seqLenPass, $cgCompPass, $trSigPass, $stemLenPass, $loopLenPass, $stemBpPrPass, $upStrNorPass, $upLenNorPass);
 					if($seqLenPass && $cgCompPass && $trSigPass && $stemLenPass && $loopLenPass && $stemBpPrPass && $upStrNorPass && $upLenNorPass){
 						$numExtracted++;
-						print(EXTRACTED ">HP$numExtracted species $SPECIES_CODE loci $chr:$lociStart-$lociEnd\n$hairpinSeq\n\n");
+						print(EXTRACTED ">HP$numExtracted species $SPECIES_CODE locus $chr:$lociStart-$lociEnd\n$hairpinSeq\n\n");
 					}
 					$numSTL++;
 				}
